Derive Macro bpf_script_derive::AddToTypeDatabase
source · #[derive(AddToTypeDatabase)]
{
// Attributes available to this derive:
#[field]
}
Implements AddToTypeDatabase for the type. If the type is a structure, it will create a new type for the structure with the same name and all its inner fields.